- Add displacement operations `left shift (\<\<)
  <xoutil.future.datetime.TimeSpan.__lshift__>`:meth: and `right shift (>>)
  <xoutil.future.datetime.TimeSpan.__rshift__>`:meth: for
  `~xoutil.future.datetime.TimeSpan`:class:.

- Add `xoutil.objects.smart_getter`:func: and
  `xoutil.objects.save_attributes`:func:.

- Document experimental module `xoutil.tasking`:mod:.

- Add extra (and experimental) module `xoutil.testing`:mod:.
